@@ -29,7 +29,7 @@ using namespace KgpgCore;
 
 SelectKeyProxyModel::SelectKeyProxyModel(QObject *parent)
 	: QSortFilterProxyModel(parent),
-	m_model(Q_NULLPTR),
+	m_model(nullptr),
 	m_showUntrusted(false)
 {
 }
@@ -97,7 +97,7 @@ SelectKeyProxyModel::rowCount(const QModelIndex &parent) const
 		return 0;
 	if (parent.isValid())
 		return 0;
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return 0;
 	return QSortFilterProxyModel::rowCount(parent);
 }
@@ -132,7 +132,7 @@ SelectKeyProxyModel::data(const QModelIndex &index, int role) const
 bool
 SelectKeyProxyModel::hasChildren(const QModelIndex &parent) const
 {
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return false;
 	return !parent.isValid();
 }
@@ -146,7 +146,7 @@ SelectKeyProxyModel::headerData(int section, Qt::Orientation orientation, int ro
 	if (orientation != Qt::Horizontal)
 		return QVariant();
 
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return QVariant();
 
 	switch (section) {
@@ -201,7 +201,7 @@ SelectSecretKeyProxyModel::rowCount(const QModelIndex &parent) const
 		return 0;
 	if (parent.isValid())
 		return 0;
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return 0;
 	return QSortFilterProxyModel::rowCount(parent);
 }
@@ -241,7 +241,7 @@ SelectSecretKeyProxyModel::data(const QModelIndex &index, int role) const
 bool
 SelectSecretKeyProxyModel::hasChildren(const QModelIndex &parent) const
 {
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return false;
 	return !parent.isValid();
 }
@@ -255,7 +255,7 @@ SelectSecretKeyProxyModel::headerData(int section, Qt::Orientation orientation,
 	if (orientation != Qt::Horizontal)
 		return QVariant();
 
-	if (m_model == Q_NULLPTR)
+	if (m_model == nullptr)
 		return QVariant();
 
 	switch (section) {
